Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/as7341_simpletest.py
    :caption: examples/as7341_simpletest.py
    :linenos:

LED test
--------

Testing the LED

.. literalinclude:: ../examples/as7341_led_test.py
    :caption: examples/as7341_led_test.py
    :linenos:

Flicker Detection
-----------------

Showing how to use flicker detection

.. literalinclude:: ../examples/as7341_flicker_detection.py
    :caption: examples/as7341_flicker_detection.py
    :linenos:

Batched Readings Example
------------------------

Example in how to get all the channel readings at the same time

.. literalinclude:: ../examples/as7341_batched_readings.py
    :caption: examples/as7341_batched_readings.py
    :linenos:
